@@ -1,24 +1,23 @@
 /*******************************************************************
-*
-* Copyright 2009  Pelladi Gabor <pelladigabor@gmail.com>
-*
-* Bovo is free software; you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation; either version 2, or (at your option)
-* any later version.
-*
-* Bovo is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with Bovo; see the file COPYING.  If not, write to
-* the Free Software Foundation, 51 Franklin Street, Fifth Floor,
-* Boston, MA 02110-1301, USA.
-*
-********************************************************************/
-
+ *
+ * Copyright 2009  Pelladi Gabor <pelladigabor@gmail.com>
+ *
+ * Bovo is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2, or (at your option)
+ * any later version.
+ *
+ * Bovo is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with Bovo; see the file COPYING.  If not, write to
+ * the Free Software Foundation, 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ *
+ ********************************************************************/
 
 /**
  * @file aifactory.h declaring the AiFactory class
@@ -38,19 +37,22 @@
 using namespace bovo;
 
 /** namespace for game engine */
-namespace bovo {
-    class Dimension;
+namespace bovo
+{
+class Dimension;
 } /* namespace bovo */
 
 /** namespace for AI stuff */
-namespace ai {
+namespace ai
+{
 
 class Ai;
 
 /**
  * Provider of AI implementations
  */
-class AiFactory : public QObject {
+class AiFactory : public QObject
+{
     Q_OBJECT
 public:
     /**
@@ -74,13 +76,13 @@ public:
      * @param player player id of this AI
      * @param demoMode indicates the current game mode
      */
-    Ai* createAi(const Dimension& dimension, KgDifficultyLevel::StandardLevel skill, Player player, DemoMode demoMode) const;
+    Ai *createAi(const Dimension &dimension, KgDifficultyLevel::StandardLevel skill, Player player, DemoMode demoMode) const;
 
     /**
      * @brief returns the available AI-s
      * @description returns a list of the names of the available AI-s
      */
-    const QStringList& aiList() const;
+    const QStringList &aiList() const;
 
     /**
      * @brief returns the current AI
